/*
 * beaglefs/inode.c - the beaglefs inode object
 *
 * Robert Love <rml@novell.com>
 */

#include <glib.h>

#include "inode.h"

struct beagle_inode {
	char *name;		/* filename */
	char *target;		/* target of the symlink, absolute file path */
	time_t time;		/* inode's m_time, c_time, and a_time */
	char *mime_type;	/* xattr: MIME Type */
	char *type;		/* xattr: Hit Type */
	char *uri;		/* xattr: URI */
	char *source;		/* xattr: Source */
	char *score;		/* xattr: Hit Score */
};

const char *
beagle_inode_get_name (beagle_inode_t *inode)
{
	g_return_val_if_fail (inode, NULL);
	return inode->name;
}

const char *
beagle_inode_get_target (beagle_inode_t *inode)
{
	g_return_val_if_fail (inode, NULL);
	return inode->target;
}

time_t
beagle_inode_get_time (beagle_inode_t *inode)
{
	g_return_val_if_fail (inode, -1);
	return inode->time;
}

const char *
beagle_inode_get_mime_type (beagle_inode_t *inode)
{
	g_return_val_if_fail (inode, NULL);
	return inode->mime_type;
}

const char *
beagle_inode_get_type (beagle_inode_t *inode)
{
	g_return_val_if_fail (inode, NULL);
	return inode->type;
}

const char *
beagle_inode_get_uri (beagle_inode_t *inode)
{
	g_return_val_if_fail (inode, NULL);
	return inode->uri;
}

const char *
beagle_inode_get_source (beagle_inode_t *inode)
{
	g_return_val_if_fail (inode, NULL);
	return inode->source;
}

const char *
beagle_inode_get_score (beagle_inode_t *inode)
{
	g_return_val_if_fail (inode, NULL);
	return inode->score;
}

/*
 * beagle_inode_new - Allocate and return a new inode object, initializing it
 * with the provided values, of which fresh copies are made.
 *
 * Returns the newly allocated inode object, which must be freed via a call to
 * beagle_inode_free().
 */
beagle_inode_t *
beagle_inode_new (const char *name,
		  const char *target,
		  time_t time_stamp,
		  const char *mime_type,
		  const char *type,
		  const char *uri,
		  const char *source,
		  const char *score)
{
	beagle_inode_t *inode;

	g_return_val_if_fail (name, NULL);
	g_return_val_if_fail (target, NULL);
	g_return_val_if_fail (mime_type, NULL);
	g_return_val_if_fail (type, NULL);
	g_return_val_if_fail (uri, NULL);
	g_return_val_if_fail (source, NULL);
	g_return_val_if_fail (score, NULL);

#if GLIB_CHECK_VERSION(2,10,0)
	inode = g_slice_new (beagle_inode_t);
# else
	inode = g_new (beagle_inode_t, 1);
#endif

	inode->name = g_strdup (name);
	inode->target = g_strdup (target);
	inode->time = time_stamp;
	inode->mime_type = g_strdup (mime_type);
	inode->type = g_strdup (type);
	inode->uri = g_strdup (uri);
	inode->source = g_strdup (source);
	inode->score = g_strdup (score);

	return inode;
}

/*
 * beagle_inode_free - free an inode object and its constituents
 */
void
beagle_inode_free (beagle_inode_t *inode)
{
	g_return_if_fail (inode);

	g_free (inode->score);
	g_free (inode->source);
	g_free (inode->uri);
	g_free (inode->type);
	g_free (inode->mime_type);
	g_free (inode->target);
	g_free (inode->name);

#if GLIB_CHECK_VERSION(2,10,0)
	g_slice_free (beagle_inode_t, inode);
# else
	g_free (inode);
#endif
}
